@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use if $] >= 5.019, 'deprecate';
 
-$CGI::Fast::VERSION='2.11';
+$CGI::Fast::VERSION='2.14';
 
 use CGI;
 use CGI::Carp;
@@ -120,9 +120,8 @@ CGI::Fast - CGI Interface for Fast CGI
 
     $COUNTER = 0;
 
-    # optional, will default to STDOUT, STDIN, STDERR
+    # optional, will default to STDOUT, STDERR
     CGI::Fast->file_handles({
-        fcgi_input_file_handle  => IO::Handle->new,
         fcgi_output_file_handle => IO::Handle->new,
         fcgi_error_file_handle  => IO::Handle->new,
     });
@@ -140,6 +139,10 @@ Scripts that perform time-consuming initialization processes, such as
 loading large modules or opening persistent database connections, will
 see large performance improvements.
 
+Note that as CGI::Fast is based on CGI.pm it is no longer advised as
+a way to write Perl web apps. See L<https://metacpan.org/pod/CGI#CGI.pm-HAS-BEEN-REMOVED-FROM-THE-PERL-CORE>
+for more information about this
+
 =head1 OTHER PIECES OF THE PUZZLE
 
 In order to use CGI::Fast you'll need the FCGI module.  See
@@ -275,14 +278,13 @@ use CGI::Fast as a drop in replacement like so:
 
 =head1 FILE HANDLES
 
-FCGI defaults to using STDIN, STDOUT, and STDERR as its filehandles - this
+FCGI defaults to using STDOUT and STDERR as its output filehandles - this
 may lead to unexpected redirect of output if you migrate scripts from CGI.pm
 to CGI::Fast. To get around this you can use the file_handles method, which
 you must do B<before> the first call to CGI::Fast->new. For example using
 IO::Handle:
 
     CGI::Fast->file_handles({
-        fcgi_input_file_handle  => IO::Handle->new,
         fcgi_output_file_handle => IO::Handle->new,
         fcgi_error_file_handle  => IO::Handle->new,
     });
@@ -291,6 +293,9 @@ IO::Handle:
         ..
     }
 
+Overriding STDIN using the C<fcgi_input_file_handle> key is also possible,
+however doing so is likely to break at least POST requests.
+
 =head1 CAVEATS
 
 I haven't tested this very much.
